@@ -12,6 +12,8 @@ def initialize_db(app: Flask):
     db.init_app(app)
     db.app = app
 
+from investing_algorithm_framework.core.models.performance_metric import \
+    PerformanceMetric
 from investing_algorithm_framework.core.models.order_status import OrderStatus
 from investing_algorithm_framework.core.models.order_type import OrderType
 from investing_algorithm_framework.core.models.order_side import OrderSide
@@ -19,6 +21,11 @@ from investing_algorithm_framework.core.models.time_unit import TimeUnit
 from investing_algorithm_framework.core.models.order import Order
 from investing_algorithm_framework.core.models.portfolio import Portfolio
 from investing_algorithm_framework.core.models.position import Position
+from investing_algorithm_framework.core.models.time_frame import TimeFrame
+from investing_algorithm_framework.core.models.time_intervals import \
+    TimeInterval
+from investing_algorithm_framework.core.models.snapshots import \
+    PositionSnapshot, PortfolioSnapshot
 
 __all__ = [
     "db",
@@ -30,5 +37,10 @@ __all__ = [
     "TimeUnit",
     "create_all_tables",
     "initialize_db",
-    "OrderStatus"
+    "OrderStatus",
+    "TimeFrame",
+    "TimeInterval",
+    "PortfolioSnapshot",
+    "PositionSnapshot",
+    "PerformanceMetric"
 ]
